Skip to contents

Provides a readable summary of the stability of thresholds and HMM state means over multiple iterative refits (the loop).

Usage

# S3 method for class 'epiquest_loop'
summary(object, ...)

Arguments

object

An object of class epiquest_loop.

...

Additional arguments passed to methods.

Value

The function prints a summary to the console and invisibly returns the object.