Generate default labels for HMM states
Source:R/generate_state_labels_hmm.R
generate_state_labels_hmm.RdProvides standardized names for hidden states based on the number of states specified. These labels are used for plot legends and summary tables to provide epidemiological interpretation to the states.
Details
The labels are assigned as follows:
2 states: "Low activity (L1)", "High activity (L2)"
3 states: "Low activity (L1)", "Medium activity (L2)", "High activity (L3)"
4 states: "Very low activity (L1)", "Low activity (L2)", "Medium activity (L3)", "High activity (L4)"