Provides a readable summary of the stability of thresholds and HMM state means over multiple iterative refits (the loop).
Usage
# S3 method for class 'epiquest_loop'
summary(object, ...)Provides a readable summary of the stability of thresholds and HMM state means over multiple iterative refits (the loop).
# S3 method for class 'epiquest_loop'
summary(object, ...)