Provides a readable summary of the calculated thresholds and the HMM configuration used to derive them.
Usage
# S3 method for class 'epiquest_thresholds'
summary(object, ...)Provides a readable summary of the calculated thresholds and the HMM configuration used to derive them.
# S3 method for class 'epiquest_thresholds'
summary(object, ...)